BankTransferRequest class

Constructors

BankTransferRequest({String? amount, String? currency, String? duration, String? email, String? frequency, String? isPermanent, String? narration, String? txRef, String? phoneNumber})
BankTransferRequest constructor
BankTransferRequest.fromJson(Map<String, dynamic> json)
Constructor to initialize BankTransferRequest from json

Properties

amount ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
duration ↔ String?
getter/setter pair
email ↔ String?
getter/setter pair
frequency ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isPermanent ↔ String?
getter/setter pair
narration ↔ String?
getter/setter pair
phoneNumber ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txRef ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts BankTransferRequest instance to a map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited