ChargeCardRequest class

Constructors

ChargeCardRequest({required String cardNumber, required String cvv, required String expiryMonth, required String expiryYear, required String currency, required String amount, required String email, required String fullName, required String txRef, String? country = FlutterwaveCurrency.NGN, String? redirectUrl, Authorization? authorization})
ChargeCardRequest constructor

Properties

amount ↔ String
getter/setter pair
authorization ↔ Authorization?
getter/setter pair
cardNumber ↔ String
getter/setter pair
country ↔ String?
getter/setter pair
currency ↔ String
getter/setter pair
cvv ↔ String
getter/setter pair
email ↔ String
getter/setter pair
expiryMonth ↔ String
getter/setter pair
expiryYear ↔ String
getter/setter pair
fullName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
redirectUrl ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txRef ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts ChargeCardRequest instance to a map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited