USSDRequest class

Constructors

USSDRequest({required String amount, required String currency, required String email, required String txRef, required String fullName, required String accountBank, required String phoneNumber})

Properties

accountBank ↔ String
getter/setter pair
amount ↔ String
getter/setter pair
currency ↔ String
getter/setter pair
email ↔ String
getter/setter pair
fullName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txRef ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance of USSDRequest to json
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited